@@ -15,19 +15,20 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "_stdint.h"
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
 #include <errno.h>
 
@@ -115,6 +116,7 @@ gst_dvd_read_src_init (GstDvdReadSrc * src)
   src->dvd_title = NULL;
 
   src->location = g_strdup ("/dev/dvd");
+  src->first_seek = TRUE;
   src->new_seek = TRUE;
   src->new_cell = TRUE;
   src->change_cell = FALSE;
@@ -162,8 +164,7 @@ gst_dvd_read_src_class_init (GstDvdReadSrcClass * klass)
       g_param_spec_int ("angle", "angle", "angle",
           1, 999, 1, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&srctemplate));
+  gst_element_class_add_static_pad_template (gstelement_class, &srctemplate);
 
   gst_element_class_set_static_metadata (gstelement_class, "DVD Source",
       "Source/File/DVD",
@@ -219,6 +220,8 @@ gst_dvd_read_src_start (GstBaseSrc * basesrc)
   src->new_seek = FALSE;
   src->change_cell = TRUE;
 
+  src->first_seek = TRUE;
+
   return TRUE;
 
   /* ERRORS */
@@ -590,7 +593,7 @@ gst_dvd_read_src_goto_title (GstDvdReadSrc * src, gint title, gint angle)
       for (j = 0; j < src->vts_tmapt->tmap[i].nr_of_entries; j++) {
         guint64 time;
 
-        time = src->vts_tmapt->tmap[i].tmu * (j + 1) * GST_SECOND;
+        time = (guint64) src->vts_tmapt->tmap[i].tmu * (j + 1) * GST_SECOND;
         GST_LOG_OBJECT (src, "Time: %" GST_TIME_FORMAT " VOBU "
             "Sector: 0x%08x %s", GST_TIME_ARGS (time),
             src->vts_tmapt->tmap[i].map_ent[j] & 0x7fffffff,
@@ -695,7 +698,7 @@ gst_dvd_read_src_get_time_for_sector (GstDvdReadSrc * src, guint sector)
   for (i = 0; i < src->vts_tmapt->nr_of_tmaps; ++i) {
     for (j = 0; j < src->vts_tmapt->tmap[i].nr_of_entries; ++j) {
       if ((src->vts_tmapt->tmap[i].map_ent[j] & 0x7fffffff) == sector)
-        return src->vts_tmapt->tmap[i].tmu * (j + 1) * GST_SECOND;
+        return (guint64) src->vts_tmapt->tmap[i].tmu * (j + 1) * GST_SECOND;
     }
   }
 
@@ -714,11 +717,13 @@ gst_dvd_read_src_get_sector_from_time (GstDvdReadSrc * src, GstClockTime ts)
   if (src->vts_tmapt == NULL || src->vts_tmapt->nr_of_tmaps < src->ttn)
     return -1;
 
-  sector = 0;
+  sector = src->vts_tmapt->tmap[src->ttn - 1].map_ent[0] & 0x7fffffff;
+
   for (j = 0; j < src->vts_tmapt->tmap[src->ttn - 1].nr_of_entries; ++j) {
     GstClockTime entry_time;
 
-    entry_time = src->vts_tmapt->tmap[src->ttn - 1].tmu * (j + 1) * GST_SECOND;
+    entry_time =
+        (guint64) src->vts_tmapt->tmap[src->ttn - 1].tmu * (j + 1) * GST_SECOND;
     if (entry_time <= ts) {
       sector = src->vts_tmapt->tmap[src->ttn - 1].map_ent[j] & 0x7fffffff;
     }
@@ -1019,7 +1024,7 @@ gst_dvd_read_src_set_property (GObject * object, guint prop_id,
       if (started) {
         g_warning ("%s: property '%s' needs to be set before the device is "
             "opened", GST_ELEMENT_NAME (src), pspec->name);
-        break;;
+        break;
       }
 
       g_free (src->location);
@@ -1238,6 +1243,13 @@ gst_dvd_read_src_do_seek (GstBaseSrc * basesrc, GstSegment * s)
   GST_DEBUG_OBJECT (src, "Seeking to %s: %12" G_GINT64_FORMAT,
       gst_format_get_name (s->format), s->position);
 
+  /* Ignore the first seek to 0, as it breaks starting playback
+   * from another chapter by seeking back to sector 0 */
+  if (src->first_seek && s->format == GST_FORMAT_BYTES && s->start == 0) {
+    src->first_seek = FALSE;
+    return TRUE;
+  }
+
   if (s->format == sector_format || s->format == GST_FORMAT_BYTES
       || s->format == GST_FORMAT_TIME) {
     guint old;
