@@ -32,22 +32,9 @@
 /* 16byte-aligns a buffer for libmpeg2 */
 #define ALIGN_16(p) ((void *)(((uintptr_t)(p) + 15) & ~((uintptr_t)15)))
 
-/* mpeg2dec changed a struct name after 0.3.1, here's a workaround */
-/* mpeg2dec also only defined MPEG2_RELEASE after 0.3.1
-   #if MPEG2_RELEASE < MPEG2_VERSION(0,3,2)
-*/
-#ifndef MPEG2_RELEASE
-#define MPEG2_VERSION(a,b,c) ((((a)&0xff)<<16)|(((b)&0xff)<<8)|((c)&0xff))
-#define MPEG2_RELEASE MPEG2_VERSION(0,3,1)
-typedef picture_t mpeg2_picture_t;
-typedef gint mpeg2_state_t;
-
-#define STATE_BUFFER 0
-#endif
-
 GST_DEBUG_CATEGORY_STATIC (mpeg2dec_debug);
-#define GST_CAT_DEFAULT (mpeg2dec_debug)
-GST_DEBUG_CATEGORY_EXTERN (GST_CAT_PERFORMANCE);
+#define GST_CAT_DEFAULT mpeg2dec_debug
+GST_DEBUG_CATEGORY_STATIC (CAT_PERFORMANCE);
 
 /* Send a warning message about decoding errors after receiving this many
  * STATE_INVALID return values from mpeg2_parse. -1 means never.
@@ -105,10 +92,10 @@ gst_mpeg2dec_class_init (GstMpeg2decClass * klass)
 
   gobject_class->finalize = gst_mpeg2dec_finalize;
 
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&src_template_factory));
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&sink_template_factory));
+  gst_element_class_add_static_pad_template (element_class,
+      &src_template_factory);
+  gst_element_class_add_static_pad_template (element_class,
+      &sink_template_factory);
   gst_element_class_set_static_metadata (element_class,
       "mpeg1 and mpeg2 video decoder", "Codec/Decoder/Video",
       "Uses libmpeg2 to decode MPEG video streams",
@@ -128,6 +115,7 @@ gst_mpeg2dec_class_init (GstMpeg2decClass * klass)
 
   GST_DEBUG_CATEGORY_INIT (mpeg2dec_debug, "mpeg2dec", 0,
       "MPEG-2 Video Decoder");
+  GST_DEBUG_CATEGORY_GET (CAT_PERFORMANCE, "GST_PERFORMANCE");
 }
 
 static void
@@ -500,7 +488,7 @@ gst_mpeg2dec_crop_buffer (GstMpeg2dec * dec, GstVideoCodecFrame * in_frame,
   info = &state->info;
   dinfo = &dec->decoded_info;
 
-  GST_CAT_LOG_OBJECT (GST_CAT_PERFORMANCE, dec,
+  GST_CAT_LOG_OBJECT (CAT_PERFORMANCE, dec,
       "Copying input buffer %ux%u (%" G_GSIZE_FORMAT ") to output buffer "
       "%ux%u (%" G_GSIZE_FORMAT ")", dinfo->width, dinfo->height,
       dinfo->size, info->width, info->height, info->size);
@@ -699,16 +687,12 @@ handle_sequence (GstMpeg2dec * mpeg2dec, const mpeg2_info_t * info)
   if (GST_VIDEO_INFO_PAR_N (vinfo) == 1 &&
       GST_VIDEO_INFO_PAR_D (vinfo) == 1 &&
       sequence->pixel_width != 0 && sequence->pixel_height != 0) {
-#if MPEG2_RELEASE >= MPEG2_VERSION(0,5,0)
     guint pixel_width, pixel_height;
+
     if (mpeg2_guess_aspect (sequence, &pixel_width, &pixel_height)) {
       vinfo->par_n = pixel_width;
       vinfo->par_d = pixel_height;
     }
-#else
-    vinfo->par_n = sequence->pixel_width;
-    vinfo->par_d = sequence->pixel_height;
-#endif
     GST_DEBUG_OBJECT (mpeg2dec, "Setting PAR %d x %d",
         vinfo->par_n, vinfo->par_d);
   }
@@ -925,12 +909,9 @@ handle_picture (GstMpeg2dec * mpeg2dec, const mpeg2_info_t * info,
       GST_BUFFER_FLAG_SET (frame->output_buffer,
           GST_VIDEO_BUFFER_FLAG_INTERLACED);
     }
-#if MPEG2_RELEASE >= MPEG2_VERSION(0,5,0)
-    /* repeat field introduced in 0.5.0 */
     if (picture->flags & PIC_FLAG_REPEAT_FIRST_FIELD) {
       GST_BUFFER_FLAG_SET (frame->output_buffer, GST_VIDEO_BUFFER_FLAG_RFF);
     }
-#endif
   }
 
   if (mpeg2dec->discont_state == MPEG2DEC_DISC_NEW_PICTURE && key_frame) {
@@ -942,11 +923,7 @@ handle_picture (GstMpeg2dec * mpeg2dec, const mpeg2_info_t * info,
       GST_TIME_FORMAT,
       (picture->flags & PIC_FLAG_PROGRESSIVE_FRAME ? "prog" : "    "),
       (picture->flags & PIC_FLAG_TOP_FIELD_FIRST ? "tff" : "   "),
-#if MPEG2_RELEASE >= MPEG2_VERSION(0,5,0)
       (picture->flags & PIC_FLAG_REPEAT_FIRST_FIELD ? "rff" : "   "),
-#else
-      "unknown rff",
-#endif
       (picture->flags & PIC_FLAG_SKIP ? "skip" : "    "),
       (picture->flags & PIC_FLAG_COMPOSITE_DISPLAY ? "composite" : "         "),
       picture->nb_fields, GST_TIME_ARGS (frame->pts));
@@ -1094,13 +1071,11 @@ gst_mpeg2dec_handle_frame (GstVideoDecoder * decoder,
     GST_DEBUG_OBJECT (mpeg2dec, "parse state %d", state);
 
     switch (state) {
-#if MPEG2_RELEASE >= MPEG2_VERSION (0, 5, 0)
       case STATE_SEQUENCE_MODIFIED:
         GST_DEBUG_OBJECT (mpeg2dec, "sequence modified");
         mpeg2dec->discont_state = MPEG2DEC_DISC_NEW_PICTURE;
         gst_mpeg2dec_clear_buffers (mpeg2dec);
         /* fall through */
-#endif
       case STATE_SEQUENCE:
         ret = handle_sequence (mpeg2dec, info);
         /* if there is an error handling the sequence
@@ -1131,10 +1106,8 @@ gst_mpeg2dec_handle_frame (GstVideoDecoder * decoder,
         GST_LOG_OBJECT (mpeg2dec,
             "Second picture header encountered. Decoding 2nd field");
         break;
-#if MPEG2_RELEASE >= MPEG2_VERSION (0, 4, 0)
       case STATE_INVALID_END:
         GST_DEBUG_OBJECT (mpeg2dec, "invalid end");
-#endif
       case STATE_END:
         GST_DEBUG_OBJECT (mpeg2dec, "end");
       case STATE_SLICE:
@@ -1185,7 +1158,7 @@ done:
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  if (!gst_element_register (plugin, "mpeg2dec", GST_RANK_PRIMARY,
+  if (!gst_element_register (plugin, "mpeg2dec", GST_RANK_SECONDARY,
           GST_TYPE_MPEG2DEC))
     return FALSE;
 
